Ord-en Ley
==========

Resume
------
Desktop program to manage lawyer's office

This project has been made to allow mainly new lawyers who wants to start her law office, 
who want have an alternative base on open source to manage their's clients, 
appointments and files.

Resumen
-------
Programa de escritorio destinado a la organización de despachos de abogados
Está orientado a cualquier abogado o despacho de abogados que quiera montar su propio 
despacho pueda tener una aplicación para la gestión de su despacho, basado en software 
libre y no viendose obligado a usar soluciones profesionales que aunque puedan ser más 
completas impliquen un gasto inicial muy elevado.

Maintenance
-----------
Author: Oscar Ramirez Jimenez

Email: tuxskar<at>gmail.com

Installation on Linux
---------------------
Using PyPI:

::

$> pip install ordenley

Alternative installation
........................
As normal python application:

::

$> python setup.py install

Run
---
As the program script is stored into bin you can run it using:

::

> ordenley

Actual version Pre-alpha
------------------------
This version allow you just work with simple clients

Features
........
- Tested (up to ~90%)
- Database located in the same position (at home/.ordenley)
- Installation easy from PyPI using "pip install ordenley"
- Show actual clients in the DB
- Modify clients from UI
- Add new clients from UI
- Remove clients from UI
